.. Copyright 2014, 2015, 2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Using Reahl in Vagrant
======================

Since Reahl 5.0 using Vagrant is no longer supported.

Use `our Docker dev box instead <install-docker>`.